function [lrtKrate,lrtSrate, dk, ds, proKbadRatio, proSbadRatio] = cLRTInference(kappa,trueS,sampleSize,simSize,alpha)
    % Inference for S and kappa based on likelihood ratio test.
    %
    %   Synopsis:
    %       [lrtKrate,lrtSrate,proKbadRatio,proSbadRatio] = cLRTInference(folder,kappa,trueS,sampleSize,simSize,alpha)
    %check arguments
    if nargin<4
        simSize = 1000;
        alpha = 0.05;
    elseif nargin<5
        alpha = 0.05;
    end
    kappaString = num2str(kappa);
    sizeString = num2str(sampleSize);
    suffix = strcat('_', kappaString, '_', sizeString);
    folder = strcat('mcmc', suffix);
    %initialize variables
    llhAtKappaSmle = zeros(simSize, 1);
    llhAtKmleS = zeros(simSize, 1);
    %read in mle data
    mleFileName = strcat(folder, '/maxMLE', suffix, '.txt');
    mleUpdated = dlmread(mleFileName);
    llh = mleUpdated(:, 1);
    %calculate log likelihood at various points
    parfor i = 1:simSize
        iString = num2str(i);
        %read in rotation matrix data
        rmsFileName = strcat(folder,'/rms/rms', suffix, '_', iString, '.bin');
        rmsSam = readRMS(rmsFileName);
        %profile likelihood for kappa
        mle = mleUpdated(i, :);
        kmle = mle(2);
        smle = romatFromAngle(mle(3), mle(4), mle(5));
        llhAtKappaSmle(i) = llhMFisherNature(kappa, smle, rmsSam);
        llhAtKmleS(i) = llhMFisherNature(kmle, trueS, rmsSam);
    end
    %read in restricted llh
    profileSFileName = strcat(folder, '/RestrictSMLE', suffix, '.txt');
    profileS = dlmread(profileSFileName);
    profileKFileName = strcat(folder, '/RestrictKMLE', suffix, '.txt');
    profileK = dlmread(profileKFileName);
    %calculate profile likelihood
    profileS = profileS(:, 1);
    profileK = profileK(:, 1);
    ds = sum((profileS - llhAtKmleS).^2);
    dk = sum((profileK - llhAtKappaSmle).^2);
    proSbadRatio = mean(profileS < llhAtKmleS);
    proKbadRatio = mean(profileK < llhAtKappaSmle);
    profileS = max(profileS, llhAtKmleS);
    profileK = max(profileK, llhAtKappaSmle);
    %inference
    lrtSrate = mean(2*(llh-profileS)<chi2inv(1-alpha,3));
    lrtKrate = mean(2*(llh-profileK)<chi2inv(1-alpha,1));
    %srate and krate
    correctedLRTRateFileName = strcat(folder,'/correctedLRTRates', suffix, '.txt');
    lrtRateFileId = fopen(correctedLRTRateFileName, 'w');
    fprintf(lrtRateFileId, 'krate: %f, badKratio: %f, srate: %f, badSratio: %f', lrtKrate, proKbadRatio, lrtSrate, proSbadRatio);
    fclose(lrtRateFileId);
%     %email yourself about the results
%     emailSubject = strcat('Corrected LRT inference for kappa=', kappaString, ', n=',sizeString, ' is done!');
%     emailBody = strcat('krate: ', num2str(lrtKrate),', badKratio: ',num2str(proKbadRatio),', srate: ', num2str(lrtSrate),', badSratio: ',num2str(proSRatio));
%     emailMe(emailSubject,emailBody);
