function y = chisqTest(d, covMat, inversed, alpha)
	%%
    % Perform a Chi Square test.
    %
	% Input:
	% 	d = x - x0, i.e., the difference betwen observed value and null value of parameters. 
    %       It must be a vector.
	%   covMat = covariance matrix
	%   inversed = a boolean value (true, false) indicate whether the covariance matrix has already been inversed.
	%   alpha = significant leval
	% Output:
	%   y = 1 or 0 indicating whether the test is significant or not
	invCovMat = covMat;
	if ~inversed
		invCovMat = inv(covMat);
	end
    if size(d, 1) == 1
        dRow = d;
        dCol = d';
    elseif size(d, 2) == 1
        dRow = d';
        dCol = d;
    else
        fprintf('d must be vector!');
        exit(1);
    end
    y = dRow * invCovMat * dCol - chi2inv(1 - alpha, numel(d));
    if y >= 0
		y = true;
		return
	end
	y = false;
