
function mat = equiClass(s)
    %%
    %   Return the 24 equivalent elements of a rotation matrix.
    %
    %   Synopsis:
    %       mat = equiClass(s)
    %   Input:
    %       s = a rotation matrix
    %   Output:
    %       mat = a 3*3*24 array which contains the 24 equivalent elements
    %       of a rotation matrix.
    %%
    %extract the 3 columns of s out
    x = s(:,1);
    y = s(:,2);
    z = s(:,3);
    %generate the quotient-4 class
    r1 = s;
    r2 = cat(2,-z,y,x);
    r3 = cat(2,x,-z,y);
    r4 = cat(2,z,y,-x);
    r5 = cat(2,x,z,-y);
    r6 = cat(2, x, -y,-z);
    %find all elements
    g1 = equiFour(r1);
    g2 = equiFour(r2);
    g3 = equiFour(r3);
    g4 = equiFour(r4);
    g5 = equiFour(r5);
    g6 = equiFour(r6);
    %return result
    mat=cat(3,g1,g2,g3,g4,g5,g6);

function mat = equiFour(s)
    %%
    %   Return the 4 equivalent elements where the last column is fixed.
    %   
    %   Synopsis:
    %       mat = equiFour(s)
    %   Input:
    %       s = a rotation matrix.
    %   Output:
    %       mat = a 3*3*4 array containing the 4 equivalent elements.
    %%
    %initial y
    mat = zeros(3,3,4);
    %%
    %extract the 3 columns of s
    x = s(:,1);
    y = s(:,2);
    z = s(:,3);
    %generate the 4 equivalent elements with last column fixed
    mat(:,:,1) = s;
    mat(:,:,2) = cat(2,y,-x,z);
    mat(:,:,3) = cat(2,-x,-y,z);
    mat(:,:,4) = cat(2,-y,x,z);
