
function [allGradsZXZ, allHessiansZXZ] = hessianZXZatMLE(kappa, sampleSize, iter)
    %%
    % Hession matrix at MLE using the ZXZ convention of Euler representation.
    %   Synopsis:
    %       [allGrads, allHessians] = hessianAtMLE(kappa, sampleSize, iter)
    %   Input: 
    %       kappa =
    %       sample size =
    %       iter = 
    %   Output:
    %       y = hessian matrix at MLE
    
    %%
    %check parameters
    if nargin < 3
       iter = 1000; 
    end
    kappaString = num2str(kappa);
    sizeString = num2str(sampleSize);
    folder = strcat('mcmc_', kappaString, '_', sizeString);
    %%
    %initialize variables
    allGradsZXZ = zeros(4, iter);
    allHessiansZXZ = zeros(4, 4, iter);
    errSubject = strcat('Exception Happens in Calculating Hessians for kappa=', kappaString, ', n=', sizeString);
    %%
    %read in updated MLEs
    file = strcat('mleZXZ_', kappaString, '_', sizeString, '.txt');
    mleZXZFileName = strcat(folder, '/', file);
    mleZXZ = dlmread(mleZXZFileName);
    %%
    parfor i = 1:iter
       %read in rotation matrix sample
       iString = num2str(i);
       rmsFileName = strcat(folder, '/rms/rms_', kappaString, '_', sizeString, '_', iString, '.bin');
       rmsFileId = fopen(rmsFileName, 'r');
       rmsSam = fread(rmsFileId, Inf, 'double');
       fclose(rmsFileId);
       rmsSam = reshape(rmsSam, [3,3,numel(rmsSam)/9]);
       %calculate hessian matrices
       mle = mleZXZ(i, :);
       [llh, grad, hessian] = llhMFisherEuler(mle(2:5), rmsSam);
       allGradsZXZ(:, i) = grad;
       allHessiansZXZ(:, :, i) = hessian;
    end
    %%write results into files
    file = strcat('gradientsZXZ_', kappaString, '_', sizeString, '.bin');
    gradientsFileName = strcat(folder, '/', file);
    safeWriteBinary(gradientsFileName, 'double', errSubject, allGradsZXZ);
    file = strcat('hessiansZXZ_', kappaString, '_', sizeString, '.bin');
    hessiansFileName = strcat(folder, '/', file);
    safeWriteBinary(hessiansFileName, 'double', errSubject, allHessiansZXZ);
    
