(*Likelihood of Matrix Fisher model using the Euler angler representation.*)
RoMatFromAngle[alpha_, beta_, gamma_] :=
  {{Cos[alpha] Cos[gamma] - 
     Sin[alpha] Sin[gamma] Cos[beta], 
    Sin[alpha] Cos[gamma] + Cos[alpha] Sin[gamma] Cos[beta], 
    Sin[gamma] Sin[beta]},
   {-Cos[alpha] Sin[gamma] - 
     Sin[alpha] Cos[gamma] Cos[beta], -Sin[alpha] Sin[gamma] + 
     Cos[alpha] Cos[gamma] Cos[beta], Cos[gamma] Sin[beta]},
   {Sin[alpha] Sin[beta], -Cos[alpha] Sin[beta], Cos[beta]}};
LogDDkenel[o_, s_, k_] := Module[{mat, temp, temp1, temp2, index, traces, trMax},
   mat = Transpose[s].o;
   traces = Table[0, {24}];
   temp = Table[0, {24}];
   (*the first 4 traces*)
   index = {1, 2, 3, 4};
   traces[[index]] = mat[[3, 3]];
   temp1 = mat[[1, 1]] + mat[[2, 2]];
   temp2 = mat[[1, 2]] - mat[[2, 1]];
   temp[[index]] = {temp1, temp2, -temp1, -temp2};
   (*the second 4 traces*)
   index = {5, 6, 7, 8};
   traces[[index]] = mat[[3, 1]];
   temp1 = mat[[2, 2]] - mat[[1, 3]];
   temp2 = mat[[1, 2]] + mat[[2, 3]];
   temp[[index]] = {temp1, temp2, -temp1, -temp2};
   (*the third 4 traces*)
   index = {9, 10, 11, 12};
   traces[[index]] = mat[[3, 2]];
   temp1 = mat[[1, 1]] - mat[[2, 3]];
   temp2 = mat[[1, 3]] + mat[[2, 1]];
   temp[[index]] = {temp1, -temp2, -temp1, temp2};
   (*the fourth 4 traces*)
   index = {13, 14, 15, 16};
   traces[[index]] = -mat[[3, 1]];
   temp1 = mat[[1, 3]] + mat[[2, 2]];
   temp2 = mat[[1, 2]] - mat[[2, 3]];
   temp[[index]] = {temp1, temp2, -temp1, -temp2};
   (*the fifth 4 traces*)
   index = {17, 18, 19, 20};
   traces[[index]] = -mat[[3, 2]];
   temp1 = mat[[1, 1]] + mat[[2, 3]];
   temp2 = mat[[1, 3]] - mat[[2, 1]];
   temp[[index]] = {temp1, temp2, -temp1, -temp2};
   (*the last 4 traces*)
   index = {21, 22, 23, 24};
   traces[[index]] = -mat[[3, 3]];
   temp1 = mat[[1, 1]] - mat[[2, 2]];
   temp2 = mat[[1, 2]] + mat[[2, 1]];
   temp[[index]] = {temp1, -temp2, -temp1, temp2};
   (*final trace*)
   traces += temp;
   (*calculate the log ...*)
   trMax = Max[traces];
   Return[trMax*k + Log[Total[Exp[k*(traces - trMax)]]]];
   ];
LlhMFisherEuler[kappa_, alpha_, beta_, gamma_, dataOm_] := Module[{s, n, i02kExp, i12kExp, i, result},
   (*
   Log likelihood function of Matrix Fisher distribution using \
Euler angle representation.
   *)
   s = RoMatFromAngle[alpha, beta, gamma];
   n = Length[dataOm];
   i02kExp = BesselI[0, 2*kappa] Exp[-2 kappa];
   i12kExp = BesselI[1, 2*kappa] Exp[-2 kappa];
   result = -n*(3*kappa + Log[i02kExp - i12kExp]);
   For[i = 1, i <= n, i++,
    result += LogDDkenel[dataOm[[i]], s, kappa];
    ];
   Return[result];
   ];

