
function [kpost,spost,krate,srate] = mcmcSample_dis(n,sInit,kInit,dataOm,tuningS,tuningK)
%%
% Synopsis:
%   [kpost, spost, krate, srate] = mcmcSample_dis(n,sInit,kInit,dataOm,tuningS,tuningK)
% 
%   Input:
%       n = the number of draws to make.
%       sInit = the initial value for s.
%       kInit = the initial value for k.
%       dataOm = the rotation matrix data.
%      
%
%   Output:
%       kpost = posterior draws for kappa, which is a vector.
%       spost = posterior draws for s, which is 3 dimensional array.
%       krate = the jumping rate for kappa, which can also be abtained from
%       the posterior draws for kappa.
%       srate = the jumpint rate for s, which can also be abtained from the
%       posterior draws for s.
    %%
    %initialize the output
    kpost=zeros(1,n);
    spost=zeros(3,3,n);
    krate=0;
    srate=0;
    %%
    %extract initial values for s and k
    sCurrent=sInit;
    kCurrent=kInit;
    %%
    %do mcmc simulation accroding to the the number of tuning parameters
        %%
        %--- mcmc simulation using fixed tuning parameters ------
        for i = 1:n
            %generate a new s
            sStar = rmfSymOne(sCurrent,tuningS);
            r1=ratioAcceptS(sStar,sCurrent,kCurrent,dataOm);
            %check whether should jump
            if r1>=1
                spost(:,:,i)=sStar;
                sCurrent=sStar;
                srate=srate+1;
            elseif binornd(1,r1)==1
                spost(:,:,i)=sStar;
                sCurrent=sStar;
                srate=srate+1;
            else
                spost(:,:,i)=sCurrent;
            end
            %generate a new k
            kStar=lognrnd(log(kCurrent),tuningK);
            r2=ratioAcceptK(sCurrent,kStar,kCurrent,dataOm);
            if r2>=1
                kpost(i)=kStar;
                kCurrent=kStar;
                krate=krate+1;
            elseif binornd(1,r2)==1
                kpost(i)=kStar;
                kCurrent=kStar;
                krate=krate+1;
            else
                kpost(i)=kCurrent;
            end
        end
        %%
        %calculate the jumping rate
        srate=srate/n;
        krate=krate/n;
