(*Functions in Mathematica for calculating MLEs*)

CheckMLEOne[kappa_, size_Integer, i_Integer, lower_Real:0.00001] := Module[
    {result, fileName, filePath, dataOm, mle1, mle2, mle3, k, alpha, beta, gamma, 
    kappaString, sizeString, iString},
   result = Table[0, {10}];
   kappaString = ToString[kappa];
   sizeString = ToString[size];
   iString = ToString[i];
   Print["Running " <> iString <> " @ " <> DateString[]];
   (*folder = "mcmc_" <> kappaString <> "_" <> sizeString;*)
   fileName = "rms_" <> kappaString <> "_" <> sizeString <> "_" <> iString <> ".bin";
   filePath = FileNameJoin[{"rms", fileName}];
   dataOm = Import[filePath, "real64"];
   dataOm = Partition[Partition[dataOm, 3], 3];
   dataOm = Transpose /@ dataOm;
   (*find mle using FindMaximum*)
   mle1 = FindMaximum[{LlhMFisherEuler[k, alpha, beta, gamma, dataOm], 
      k > lower, 0 <= alpha <= 2 Pi, 0 <= beta <= 2 Pi, 0 <= gamma <= 2 Pi}, 
      {{k, kappa}, {alpha, 2.3}, {beta, 1.1}, {gamma, 5.9}}];
   mle1 = mle1 /. Rule -> (#2 &); 
   mle1 = Flatten[mle1];
   result[[{1, 2, 3, 4, 5}]] = mle1;
   (*
   mle2 = FindMaximum[{LlhMFisherEuler[k, alpha, beta, gamma, dataOm], 
      k > lower, 0 <= alpha <= 2 Pi, 0 <= beta <= 2 Pi, 0 <= gamma <= 2 Pi}, 
      {{k, mle1[[2]]}, {alpha, mle1[[3]]}, {beta, mle1[[4]]}, {gamma, mle1[[5]]}}];
   mle2 = mle2 /. Rule -> (#2 &);
   mle2 = Flatten[mle2];
   result[[{6, 7, 8, 9, 10}]] = mle2;
   *)
   mle3 = Maximize[{LlhMFisherEuler[k, alpha, beta, gamma, dataOm], 
      k > lower, 0 <= alpha <= 2 Pi, 0 <= beta <= 2 Pi, 0 <= gamma <= 2 Pi}, 
      {k, alpha, beta, gamma}];
   mle3 = mle3 /. Rule -> (#2 &);
   mle3 = Flatten[mle3];
   (*result[[{11, 12, 13, 14, 15}]] = mle3;*)
   result[[{6, 7, 8, 9, 10}]] = mle3;
   Return[result];
];

ParaCheckMLE[kappa_, size_Integer, iter_Integer, lower_Real:0.00001] := Module[
    {result, output, kappaString, sizeString},
    result = ParallelTable[CheckMLEOne[kappa, size, i, lower], {i, 1, iter}];
    (*write the result into a file*)
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    output = "CheckMLE_" <> kappaString <> "_" <> sizeString <> ".txt";
    (*folder = "mcmc_" <> kappaString <> "_" <> sizeString;*)
    (*output = FileNameJoin[{folder, output}];*)
    Export[output, result, "Table"];
];

MLEOne[folder_String, kappa_, size_Integer, i_Integer] := 
  Module[{fileName, filePath, dataOm, mle, k, alpha, beta, gamma},
   fileName = 
    "rms_" <> ToString[kappa] <> "_" <> ToString[size] <> "_" <> 
     ToString[i] <> ".bin";
   filePath = FileNameJoin[{folder, "rms", fileName}];
   dataOm = Import[filePath, "real64"];
   dataOm = Partition[Partition[dataOm, 3], 3];
   dataOm = Transpose /@ dataOm;
   mle = Maximize[{LlhMFisherEuler[k, alpha, beta, gamma, dataOm], 
      k > 0}, {k, alpha, beta, gamma}];
   mle[[2]] = {k, alpha, beta, gamma} /. mle[[2]];
   Return[Flatten[mle]];
];

ParaMLE[folder_String, kappa_, size_Integer, iter_Integer: 1000] := 
  Module[{result, output},
   result = 
    ParallelTable[MLEOne[folder, kappa, size, i], {i, 1, iter}];
   (*write the result into a file*)
   
   output = 
    "MLE_" <> ToString[kappa] <> "_" <> ToString[size] <> ".txt";
   output = FileNameJoin[{folder, output}];
   Export[output, result, "Table"];
];

MLE[folder_String, kappa_, size_Integer, iter_Integer: 1000] := 
  Module[{result, output},
   result = Table[MLEOne[folder, kappa, size, i], {i, 1, iter}];
   (*write the result into a file*)
   
   output = "MLE_" <> ToString[kappa] <> "_" <> ToString[size] <> ".txt";
   output = FileNameJoin[{folder, output}];
   Export[output, result, "Table"];
];

CheckMLE[kappa_, size_Integer, iter_Integer, lower_Real:0.00001] := Module[
    {result, output, kappaString, sizeString},
    result = Table[CheckMLEOne[kappa, size, i, lower], {i, 1, iter}];
    (*write the result into a file*)
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    output = "CheckMLE_" <> kappaString <> "_" <> sizeString <> ".txt";
    (*folder = "mcmc_" <> kappaString <> "_" <> sizeString;*)
    (*output = FileNameJoin[{folder, output}];*)
    Export[output, result, "Table"];
];
