(*Functions in Mathematica for calculating profile MLEs*)

RestrictKMLEOne[kappa_, size_Integer, i_Integer] := Module[
    {fileName, filePath, dataOm, mle, alpha, beta, gamma, kappaString, sizeString, iString},
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    iString = ToString[i];    
    Print["Running RestrictKMLEOne " <> iString <> " @ " <> DateString[]];
    fileName = "rms_" <> kappaString <> "_" <> sizeString <> "_" <> iString <> ".bin";
    filePath = FileNameJoin[{"rms", fileName}];
    dataOm = Import[filePath, "real64"];
    dataOm = Partition[Partition[dataOm, 3], 3];
    dataOm = Transpose /@ dataOm;
    mle = Maximize[{LlhMFisherEuler[kappa, alpha, beta, gamma, dataOm]}, {alpha, beta, gamma}];
    mle = mle /. Rule -> (#2 &); 
    mle = Flatten[mle];
    Return[mle];
];

RestrictKMLE[kappa_, size_Integer, iter_Integer:1000] := Module[
    {result, output, kappaString, sizeString},
    result = Table[RestrictKMLEOne[kappa, size, i], {i, 1, iter}];
    (*write the result into a file*)
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    output = "RestrictKMLE_" <> kappaString <> "_" <> sizeString <> ".txt";
    (*output = FileNameJoin[{folder, output}];*)
    Export[output, result, "Table"];
];

ParaRestrictKMLE[kappa_, size_Integer, iter_Integer:1000] := Module[
    {result, output, kappaString, sizeString},
    result = ParallelTable[RestrictKMLEOne[kappa, size, i], {i, 1, iter}];
    (*write the result into a file*)
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    output = "RestrictKMLE_" <> kappaString <> "_" <> sizeString <> ".txt";
    (*output = FileNameJoin[{folder, output}];*)
    Export[output, result, "Table"];
];

RestrictSMLEOne[kappa_, size_Integer, i_Integer] := Module[
    {fileName, filePath, dataOm, mle, k, kappaString, sizeString, iString},
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    iString = ToString[i];
    Print["Running RestrictSMLEOne " <> iString <> " @ " <> DateString[]];
    fileName = "rms_" <> kappaString <> "_" <> sizeString <> "_" <> iString <> ".bin";
    filePath = FileNameJoin[{"rms", fileName}];
    dataOm = Import[filePath, "real64"];
    dataOm = Partition[Partition[dataOm, 3], 3];
    dataOm = Transpose /@ dataOm;
    mle = Maximize[{LlhMFisherEuler[k, 2.3, 1.1, 5.9, dataOm], k > 0}, {k}];
    mle = mle /. Rule -> (#2 &);
    mle = Flatten[mle];
    Return[mle];
];

RestrictSMLE[kappa_, size_Integer, iter_Integer:1000] := Module[
    {result, output, kappaString, sizeString},
    result = Table[RestrictSMLEOne[kappa, size, i], {i, 1, iter}];
    (*write the result into a file*)
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    output = "RestrictSMLE_" <> kappaString <> "_" <> sizeString <> ".txt";
    (*output = FileNameJoin[{folder, output}];*)
    Export[output, result, "Table"];
];

ParaRestrictSMLE[kappa_, size_Integer, iter_Integer:1000] := Module[
    {result, output, kappaString, sizeString},
    result = ParallelTable[RestrictSMLEOne[kappa, size, i], {i, 1, iter}];
    (*write the result into a file*)
    kappaString = ToString[kappa];
    sizeString = ToString[size];
    output = "RestrictSMLE_" <> kappaString <> "_" <> sizeString <> ".txt";
    (*output = FileNameJoin[{folder, output}];*)
    Export[output, result, "Table"];
];
