
function y = rangleOne(k)
%%
%   Generate an observation from the random rangle distribution 
%   defined by equation (3) in the manuscript.
%
%   Synopsis:
%       y = rangleOne(k)
%   Input:
%       k = the parameter for the random angle distribution
%   Output:
%       y = an observation from the random angle distribution
%%
%   twok
    if k<0
       k = 1e-20; 
    end
    twok=2*k;
    while 1
        %generate u~U(0,1)
        u=unifrnd(0,1);
        %transform u by F^(-1)(u)
        x=sin((u-0.5)*pi);
        %generate v~U(0,1)
        v=unifrnd(0,1);
        %calculate acceptance ratio
        if k<=0.25
            p=(1-x)*exp(twok*(1+x))/2;
        else
            p=twok*(1-x)*exp(twok*(x-1)+1);
        end
        if v<=p
            break;
        end
    end
    y=acos(x);
    if(binornd(1,0.5)==1)
        y=-y;
    end
