
function y = ratioAcceptK(s, kStar, k, dataOm)
    %%
    %   The acceptance ratio of kappa when S is fixed.
    %
    %   Synopsis:
    %       y = ratioAcceptK(s, kStar, k, dataOm)
    %   Input:
    %       s = the current s which is the center rotation matrix.
    %       kStar = a proposal for k.
    %       k = the current value for kappa which is the parameter for the
    %       random angle distribution.
    %       dataOm = the rotation matrix data.
    %   Output:
    %       y = the ratio for accepting the kStar which is a proposal for
    %       k.
    %%
    %calculate intermediate results
    %scaled bessel function for 2*kStar
    i02kStarExp=besseli(0,2*kStar,1);
    i12kStarExp=besseli(1,2*kStar,1);
    %scaled bessel function for 2*k
    i02kExp=besseli(0,2*k,1);
    i12kExp=besseli(1,2*k,1);
    %%
    %calculate the first part of log ratioAcceptK
    %get the dim of dataOm
    n=size(dataOm,3);
    if(k>150)
        temp = 3*k-log(4*k)-0.5*log(4*pi*k);
    else
        temp = i02kExp - i12kExp;
        temp = log(temp)+3*k;
    end
    if(kStar>150)
        tempStar = 3*kStar - log(4*kStar)-0.5*log(4*pi*kStar);
    else
        tempStar = i02kStarExp-i12kStarExp;
        tempStar = log(tempStar)+3*kStar;
    end
    y = (temp - tempStar)*n;
    %%
    %calculate the second part of log ratioAcceptK
    %first construct two vectors to store intermediate data
    tempStar = zeros(1,n);
    temp = tempStar;
    %calculate log kenel
    for i = 1:n
        tempStar(i) = logDDkenel(dataOm(:,:,i),s,kStar);
        temp(i) = logDDkenel(dataOm(:,:,i),s,k);
    end
    y=y+sum(tempStar-temp);
    %%
    %calcualte the third part of log ratioAcceptK
    if k>150
        part3 = log(sqrt(1.5));
    else
        if k>0.01 
            R2k = i12kExp/i02kExp;
            k_kR2k = k - k*R2k;
            part3 = 0.5*log(2*k_kR2k*(1+R2k)+R2k^2-2*R2k)-log(k_kR2k)+log(k);
        else
            R2k=i12kExp/i02kExp;
            part3=0.5*log(2*k*(1+R2k)/(1-R2k)+1-1/(1-R2k)^2);
        end
    end
    if kStar>150
        part3Star = log(sqrt(1.5));
    else
        if kStar>0.01
            R2kStar = i12kStarExp/i02kStarExp;
            k_kR2kStar = kStar - kStar*R2kStar;
            part3Star = 0.5*log(2*k_kR2kStar*(1+R2kStar)+R2kStar^2-2*R2kStar)-log(k_kR2kStar)+log(kStar);
        else
            R2kStar=i12kStarExp/i02kStarExp;
            part3Star = 0.5*log(2*kStar*(1+R2kStar)/(1-R2kStar)+1-1/(1-R2kStar)^2);
        end
    end
    y=y+part3Star-part3;
    %since the value of the ratio doesn't matter when ratio>1, set it as 2
    %to avoid numerical problems if ratio>2
    if y>0
        y=2;
    else
        y=exp(y);
    end
    
