
function y = rmfSym(n,s,k)
%%
%   Generate values from the matrix Fisher distribution used in the manuscript.
%
%   Synopsis:
%       y = rmfSym(n,s,k)
%   Input:
%       n = the number of rotation matrices to be genrated
%       s = the center rotation matrix
%       k = the parameter for the random angle distribution
    %%
    %generate random unit vectors
    ranVector = normrnd(0,1,n,3);
    ranVector = ranVector./repmat(sqrt(sum(ranVector.*ranVector,2)),1,3);
    %generate a random angle vector
    angle = rangle(n,k);
    %%
    %construct a 3 dimensional array to store result
    y=zeros(3,3,n);
    for i = 1:n
       y(:,:,i)=orientmatOne(ranVector(i,:),angle(i),s); 
    end
    %return result
    
    

function y = rangle(n,k)
%%
%   Synopsis:
%       y = rangle(n,k)
%   Input:
%       n = the number of random angles to be generated.
%       k = the parameter for the random angle distribution.
%   Output:
%       y = a vector of length n containg observations from the random
%       angle distribution.
%%
%construct a vector to store the result
y=zeros(1,n);
for i=1:n
    y(i)=rangleOne(k);
end
