
function safeWriteText(fileName,errSubject,varargin)
    %%
    %   Safely write some data into a file. It allows you to recover the
    %   running program if exception happens. For example, if the program is run on
    %   a server with limited hard space for you, exception happens if
    %   there's no more space for you to write data. The program will wait
    %   for you to fix the problem and continue running. In the case of no
    %   enough space, you can free the disk (e.g. copy running result to
    %   other place) and then continue running the program.
    %
    %   Synopsis:
    %       safeWriteBinary(fileName, precision, errSubject, varargin)
    %   Input:
    %       fileName = the path of the file that you want to write the data
    %       into.
    %       precision = the format of the data, usually is double.
    %       errSubject = the email subject to use in order to notify you
    %       when error happens. If it's empty (i.e. []), then there will no email notification. 
    %       varargin = extra arguments which contains the data to be write
    %       into the file. 
    %%
    %message shown in the message box
    message='Please read the error message printed to the console. After fixing the problem, you can click OK to continue the program.';
    %%
    %try to open the file
    fileId = fopen(fileName,'w');
    while fileId<0
        %email and text yourself about the exception
        errMessage = sprintf('Failed to open file for write. \nPlease make sure there is enough space on the disk and you have access to the file.\r\n');
        fprintf(errMessage);
        if(~isempty(errSubject))
            emailMe(errSubject,errMessage);
        end
        waitfor(msgbox(message));
        fileId = fopen(fileName,'w');
    end
    %%
    %try to write data into the file
    fprintf(fileId,varargin);
    fclose(fileId);