
function [sFkDistance,kfCenter,sfCenter] = sdist(kpost,spost,rms,dropSize)
    %%
    %   Find center posterior point and calculate distance between each posterior draws and the center point.
    %
    %   Synopsis:
    %       [sFkDistance,kfCenter,sfCenter] = sdist(kpost,spost,rms,dropSize)
    %   Input:
    %       dropSize = the burn-in size.
    %   Output:
    %       kfCenter = center kappa vector from data.
    %       sfCenter = center s vector using kappa from data.

    %--------------- initialize variables ------------------
    %jump rate
    sfCenter = zeros(3,3);
    kfCenter = 0;
    %------------------------------------------------------
    kpostUsed = kpost((dropSize+1):numel(kpost));
    spostUsed = spost(:,:,(dropSize+1):size(spost,3));
    %find the center for s and kappa
    maxLogPostFk = - inf;
    lenUsed = numel(kpostUsed);
    for j = 1:lenUsed
        tempLogPostFk = logpost(spostUsed(:,:,j),kpostUsed(j),rms);
        if tempLogPostFk>maxLogPostFk
            maxLogPostFk = tempLogPostFk;
            sfCenter = spostUsed(:,:,j);
            kfCenter = kpostUsed(j);
        end
    end
    %-calculate the distance between a draw of s and the posterior mode-
    sFkDistance = zeros(1,lenUsed);
    pmodeFkClass = equiClass(sfCenter);
    for j = 1:lenUsed
        sFkDistance(j) = minmaxAngle(spostUsed(:,:,j),pmodeFkClass);
    end
