function [sJumpRate, kJumpRate] = writeLogPost(kappa, sampleSize, simSize)
    %---------------------------------------------------------------------------------
    %   Synopsis:
    %   Input:
    %       kappa = value of kappa used in the simulation.
    %       sampleSize = sample size used in the simulation.
    %       simSize = the number of mcmc samples.
    %       alpha = significant level.
    %-----------------------------------------------------------------------------------
    %check passing of parameter
    if nargin < 3
        simSize = 1000;
    end
    %--------------------------------------------------------------------------------
    kJumpRate = zeros(simSize, 1);
    sJumpRate = zeros(simSize, 1);
    %--------------------------------------------------------------------------------
    kappaString = num2str(kappa);
    sizeString = num2str(sampleSize);
    suffix = strcat('_', kappaString, '_', sizeString);
    folder = strcat('mcmc', suffix);
    errSubject = strcat('Exception happens when writing log posteriors');
    % calcualte log post for each simulation and write results into files
    parfor i = 1:simSize
       iString = num2str(i);
       %read in a data set of k
       kFileName = strcat(folder, '/kpost', suffix, '_', iString, '.bin');
       [kpost, kJumpRate(i)] = readPostK(kFileName, 0);
       %read in data set of s
       sFileName = strcat(folder, '/spost', suffix, '_', iString, '.bin');
       [spost, sJumpRate(i)] = readPostS(sFileName, 0);
       %read in rotation matrix data
       rmFileName = strcat(folder, '/rms/rms', suffix, '_', iString, '.bin');
	rmSam = readRMS(rmFileName);
       %log posteriors 
       n = numel(kpost);
       lps = zeros(n, 1);
       for j = 1:n
            lps(j) = logpost(spost(:,:,j), kpost(j), rmSam);
       end
       %write the log posteriors into files
       lpsFileName = strcat(folder, '/lps', suffix, '_', iString, '.bin');
       safeWriteBinary(lpsFileName, 'double', errSubject, lps);
    end
    % write kJumpRate into file
    kJumpRateFileName = strcat(folder, '/kJumpRate', suffix, '.bin');
    safeWriteBinary(kJumpRateFileName, 'double', errSubject, kJumpRate);
    %write sJumpRate into a file
    sJumpRateFileName = strcat(folder, '/sJumpRate', suffix, '.bin');
    safeWriteBinary(sJumpRateFileName, 'double', errSubject, sJumpRate);
    %report progress via email
    emailSubject = strcat('100% of log posterior for k=', kappaString, ', n=', sizeString, ' is done.');
    emailBody = 'As the title.';
    disp(emailSubject);
    emailMe(emailSubject, emailBody);
